@@ -1,17 +1,17 @@
 package Bible::OBML;
 # ABSTRACT: Open Bible Markup Language parser and renderer
 
-use 5.014;
+use 5.020;
 
 use exact;
 use exact::class;
 use Text::Balanced qw( extract_delimited extract_bracketed );
 use Text::Wrap 'wrap';
 use Bible::OBML::HTML;
-use Bible::Reference 1.02;
+use Bible::Reference 1.05;
 use Clone 'clone';
 
-our $VERSION = '1.14'; # VERSION
+our $VERSION = '1.15'; # VERSION
 
 has bible    => 'Protestant';
 has acronyms => 1;
@@ -479,10 +479,10 @@ Bible::OBML - Open Bible Markup Language parser and renderer
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
-=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bible-OBML.svg)](https://travis-ci.org/gryphonshafer/Bible-OBML)
-[![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bible-OBML/badge.png)](https://coveralls.io/r/gryphonshafer/Bible-OBML)
+=for markdown [![test](https://github.com/gryphonshafer/Bible-OBML/workflows/test/badge.svg)](https://github.com/gryphonshafer/Bible-OBML/actions?query=workflow%3Atest)
+[![codecov](https://codecov.io/gh/gryphonshafer/Bible-OBML/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Bible-OBML)
 
 =for test_synopsis my(
     $obml_text_content, $data_structure, $skip_wrapping, $skip_smartify,
@@ -717,11 +717,11 @@ L<MetaCPAN|https://metacpan.org/pod/Bible::OBML>
 
 =item *
 
-L<Travis CI|https://travis-ci.org/gryphonshafer/Bible-OBML>
+L<GitHub Actions|https://github.com/gryphonshafer/Bible-OBML/actions>
 
 =item *
 
-L<Coveralls|https://coveralls.io/r/gryphonshafer/Bible-OBML>
+L<Codecov|https://codecov.io/gh/gryphonshafer/Bible-OBML>
 
 =item *
 
@@ -741,9 +741,10 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Gryphon Shafer.
+This software is Copyright (c) 2014-2021 by Gryphon Shafer.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
